@@ -9,7 +9,9 @@ import (
 
 	configapiv1 "github.com/openshift/api/config/v1"
 	imageregistryv1 "github.com/openshift/api/imageregistry/v1"
+	"github.com/openshift/cluster-image-registry-operator/defaults"
 	regopclient "github.com/openshift/cluster-image-registry-operator/pkg/client"
+	"github.com/openshift/cluster-image-registry-operator/pkg/envvar"
 	"github.com/openshift/cluster-image-registry-operator/pkg/storage/azure"
 	"github.com/openshift/cluster-image-registry-operator/pkg/storage/emptydir"
 	"github.com/openshift/cluster-image-registry-operator/pkg/storage/gcs"
@@ -41,9 +43,9 @@ func (m *MultiStoragesError) Error() string {
 }
 
 type Driver interface {
-	ConfigEnv() ([]corev1.EnvVar, error)
+	ConfigEnv() (envvar.List, error)
 	Volumes() ([]corev1.Volume, []corev1.VolumeMount, error)
-	Secrets() (map[string]string, error)
+	VolumeSecrets() (map[string]string, error)
 	CreateStorage(*imageregistryv1.Config) error
 	StorageExists(*imageregistryv1.Config) (bool, error)
 	RemoveStorage(*imageregistryv1.Config) (bool, error)
@@ -51,7 +53,7 @@ type Driver interface {
 	ID() string
 }
 
-func newDriver(cfg *imageregistryv1.ImageRegistryConfigStorage, kubeconfig *rest.Config, listers *regopclient.Listers) (Driver, error) {
+func NewDriver(cfg *imageregistryv1.ImageRegistryConfigStorage, kubeconfig *rest.Config, listers *regopclient.Listers) (Driver, error) {
 	var names []string
 	var drivers []Driver
 
@@ -63,7 +65,7 @@ func newDriver(cfg *imageregistryv1.ImageRegistryConfigStorage, kubeconfig *rest
 	if cfg.S3 != nil {
 		names = append(names, "S3")
 		ctx := context.Background()
-		drivers = append(drivers, s3.NewDriver(ctx, cfg.S3, kubeconfig, listers))
+		drivers = append(drivers, s3.NewDriver(ctx, cfg.S3, listers))
 	}
 
 	if cfg.Swift != nil {
@@ -102,18 +104,6 @@ func newDriver(cfg *imageregistryv1.ImageRegistryConfigStorage, kubeconfig *rest
 	return nil, &MultiStoragesError{names}
 }
 
-func NewDriver(cfg *imageregistryv1.ImageRegistryConfigStorage, kubeconfig *rest.Config, listers *regopclient.Listers) (Driver, error) {
-	drv, err := newDriver(cfg, kubeconfig, listers)
-	if err == ErrStorageNotConfigured {
-		*cfg, _, err = GetPlatformStorage(listers)
-		if err != nil {
-			return nil, fmt.Errorf("unable to get storage configuration from cluster install config: %s", err)
-		}
-		drv, err = newDriver(cfg, kubeconfig, listers)
-	}
-	return drv, err
-}
-
 // GetPlatformStorage returns the storage configuration that should be used
 // based on the cloud platform we are running on, as determined from the
 // infrastructure configuration. Also it returns the recommend number of
@@ -159,8 +149,20 @@ func GetPlatformStorage(listers *regopclient.Listers) (imageregistryv1.ImageRegi
 		cfg.GCS = &imageregistryv1.ImageRegistryConfigStorageGCS{}
 		replicas = 2
 	case configapiv1.OpenStackPlatformType:
-		cfg.Swift = &imageregistryv1.ImageRegistryConfigStorageSwift{}
-		replicas = 2
+		isSwiftEnabled, err := swift.IsSwiftEnabled(listers)
+		if err != nil {
+			return imageregistryv1.ImageRegistryConfigStorage{}, replicas, err
+		}
+		if !isSwiftEnabled {
+			cfg.PVC = &imageregistryv1.ImageRegistryConfigStoragePVC{
+				Claim: defaults.PVCImageRegistryName,
+			}
+			replicas = 1
+		} else {
+			cfg.Swift = &imageregistryv1.ImageRegistryConfigStorageSwift{}
+			replicas = 2
+		}
+
 	// Unknown platforms or LibVirt: we configure image registry using
 	// EmptyDir storage.
 	case configapiv1.LibvirtPlatformType:
